using System;
using System.Configuration;
using System.Globalization;
using System.IO;
using System.Runtime.Serialization.Formatters.Binary;
using Microsoft.Practices.EnterpriseLibrary.Common;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Transformer;

namespace EnterpriseLibrary.Extensions
{
	/// <summary>
	/// Summary description for BinaryTranformer.
	/// </summary>
	public class BinaryTranformer : TransformerProvider
	{
		public override object Serialize(object value)
		{
			ArgumentValidation.CheckForNullReference(value, "value");
		
			byte[] buffer = null;

			using (MemoryStream ms = new MemoryStream())
			{
				BinaryFormatter formatter = new BinaryFormatter();
				formatter.Serialize(ms, value);
				buffer = new byte[ms.Length];
				ms.Position = 0;
				ms.Read(buffer, 0, (int)ms.Length);
				ms.Flush();
			}
			
			return buffer;
		}
	
		public override object Deserialize(object section)
		{
			object returnConfigObject = null;
			BinaryFormatter formatter = new BinaryFormatter();

			using (MemoryStream ms = new MemoryStream((byte[])section))
			{
				returnConfigObject = formatter.Deserialize(ms);
			}

			return returnConfigObject;
		}
	
		public override void Initialize(ConfigurationView configurationView)
		{
		}
	}
}
