using System.Xml.Serialization;
using Microsoft.Practices.EnterpriseLibrary.Configuration;

namespace EnterpriseLibrary.Extensions.Configuration
{
    /// <summary>
    /// <para>Represents a storage provider to read and write data in configuration from an Xml file.</para>
    /// </summary>    	
    [XmlRoot("storageProvider", Namespace=ConfigurationSettings.ConfigurationNamespace)]
    public class DatabaseStorageProviderData : StorageProviderData
    {
        private string strDatabaseInstance;
		private string getStoredProcedure;
		private string setStoredProcedure;

        public DatabaseStorageProviderData() : this(string.Empty)
        {
        }

        public DatabaseStorageProviderData(string name) : this(name, string.Empty, string.Empty, string.Empty)
        {
        }

        public DatabaseStorageProviderData(string name, string dbInstanceString, string getStoredProcedure, string setStoredProcedure) : base(name, typeof(DatabaseStorageProvider).AssemblyQualifiedName)
        {
            this.strDatabaseInstance = dbInstanceString;
            this.getStoredProcedure = getStoredProcedure;
            this.setStoredProcedure = setStoredProcedure;
        }

        [XmlAttribute("databaseInstance")]
        public string DatabaseInstance
        {
            get { return strDatabaseInstance; }
			set {strDatabaseInstance = value;}
        }

		[XmlAttribute("getStoredProcedure")]
		public string GetStoredProcedure
		{
			get { return this.getStoredProcedure; }
			set {this.getStoredProcedure = value; }
		}

		[XmlAttribute("setStoredProcedure")]
		public string SetStoredProcedure
		{
			get { return this.setStoredProcedure; }
			set {this.setStoredProcedure = value; }
		}

		[XmlIgnore]
		public override string TypeName
		{
			get { return typeof(DatabaseStorageProvider).AssemblyQualifiedName; }
			set
			{
			}
		}

		public override object Clone()
        {
            return new DatabaseStorageProviderData(Name, strDatabaseInstance, getStoredProcedure,  setStoredProcedure);
        }
    }
}