using System;
using System.ComponentModel;
using System.Drawing.Design;
using System.Windows.Forms;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design.Validation;
using Microsoft.Practices.EnterpriseLibrary.Data.Configuration.Design;

namespace EnterpriseLibrary.Extensions.Configuration.Design
{
	[ServiceDependency(typeof(ILinkNodeService))]
	[ServiceDependency(typeof(IXmlIncludeTypeService))]
	[ServiceDependency(typeof(INodeCreationService))]
	public class DatabaseStorageProviderNode : StorageProviderNode
    {
		private InstanceNode instanceNode;
		private ConfigurationNodeChangedEventHandler onInstanceNodeRemoved;
		private ConfigurationNodeChangedEventHandler onInstanceNodeRenamed;
		private DatabaseStorageProviderData databaseStorageProviderData;

        public DatabaseStorageProviderNode() : this(new DatabaseStorageProviderData(SR.DbStorageProviderNodeName))
        {
        }

        public DatabaseStorageProviderNode(DatabaseStorageProviderData data) : base(data)
        {
            if (data == null)
            {
                throw new ArgumentNullException("data");
            }
            this.databaseStorageProviderData = data;
			this.onInstanceNodeRemoved += new ConfigurationNodeChangedEventHandler(OnInstanceNodeRemoved);
			this.onInstanceNodeRenamed += new ConfigurationNodeChangedEventHandler(OnInstanceNodeRenamed);
        }

        [Browsable(false)]
        public virtual DatabaseStorageProviderData DatabaseStorageProviderData
        {
            get { return this.databaseStorageProviderData; }
        }

		[Required]
		[Editor(typeof(ReferenceEditor), typeof(UITypeEditor))]
		[ReferenceType(typeof(InstanceNode))]    
		[SRCategory(SR.Keys.CategoryGeneral)]
		public InstanceNode DatabaseInstance
		{
			get { return instanceNode; }
			set
			{
				ILinkNodeService service = GetService(typeof(ILinkNodeService)) as ILinkNodeService;
				instanceNode = service.CreateReference(instanceNode, value, onInstanceNodeRemoved, onInstanceNodeRenamed) as InstanceNode;
				this.databaseStorageProviderData.DatabaseInstance = string.Empty;
				if (instanceNode != null)
				{
					this.databaseStorageProviderData.DatabaseInstance = instanceNode.Name;	
				}
			}
		}
		
        [Required]
        [SRDescription(SR.Keys.DbStorageProviderNodeGetSPDescription)]
        [SRCategory(SR.Keys.CategoryGeneral)]
        public string GetConfigStoredProcedure
        {
            get { return this.databaseStorageProviderData.GetStoredProcedure; }
            set { this.databaseStorageProviderData.GetStoredProcedure = value; }
        }

        [Required]
        [SRDescription(SR.Keys.DbStorageProviderNodeSetSPDescription)]
        [SRCategory(SR.Keys.CategoryGeneral)]
        public string SetConfigStoredProcedure
        {
            get { return this.databaseStorageProviderData.SetStoredProcedure; }
            set { this.databaseStorageProviderData.SetStoredProcedure = value; }
        }

        [Required]
        [SRCategory(SR.Keys.CategoryGeneral)]
        [SRDescription(SR.Keys.DbStorageProviderNodeTypeNameDescription)]
        [ReadOnly(true)]
        public string TypeName
        {
            get { return this.databaseStorageProviderData.TypeName; }
        }
	
		/// <summary>
		/// See <see cref="ConfigurationNode.ResolveNodeReferences"/>.
		/// </summary>
		public override void ResolveNodeReferences()
		{
			base.ResolveNodeReferences();
			InstanceCollectionNode instanceCollectionNode = Hierarchy.FindNodeByType(typeof(InstanceCollectionNode)) as InstanceCollectionNode;
			DatabaseInstance = Hierarchy.FindNodeByName(instanceCollectionNode, this.databaseStorageProviderData.DatabaseInstance) as InstanceNode;
		}

		private void OnInstanceNodeRemoved(object sender, ConfigurationNodeChangedEventArgs e)
		{
			this.instanceNode = null;
		}

		private void OnInstanceNodeRenamed(object sender, ConfigurationNodeChangedEventArgs e)
		{
			this.databaseStorageProviderData.DatabaseInstance = e.Node.Name;
		}
	}
}