using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing.Design;
using System.Windows.Forms;
using EnterpriseLibrary.Extensions.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design.Validation;

namespace EnterpriseLibrary.Extensions.Configuration.Design
{
    [Image(typeof(TransformerNode))]
    public class MvpSerializerTransformerNode : TransformerNode
    {
        private MvpSerializerTransformerData mvpSerializerTransformerData;

		public MvpSerializerTransformerNode() : this(new MvpSerializerTransformerData(SR.MvpSerializerTransformerNodeFriendlyName))
        {
        }

        public MvpSerializerTransformerNode(MvpSerializerTransformerData mvpSerializerTransformerData) : base(mvpSerializerTransformerData)
        {
            this.mvpSerializerTransformerData = mvpSerializerTransformerData;
        }

        [Required]
		[SRCategory(SR.Keys.CategoryGeneral)]
        [SRDescription(SR.Keys.MvpSerializerTransformerNodeSerializerDescription)]
        [ReadOnly(true)]
        public string TypeName
        {
            get { return mvpSerializerTransformerData.TypeName; }
            set { mvpSerializerTransformerData.TypeName = value; }
        }

		[Required]
		[Editor(typeof(TypeSelectorEditor), typeof(UITypeEditor))]
		[BaseType(typeof(System.Xml.Serialization.XmlSerializer))]
		[SRCategory(SR.Keys.CategoryGeneral)]
		[SRDescription(SR.Keys.MvpSerializerTransformerNodeSerializerDescription)]
		public string SerializerType
		{
			get { return mvpSerializerTransformerData.SerializationType; }
			set { mvpSerializerTransformerData.SerializationType = value; }
		}


        [Browsable(false)]
        public override TransformerData TransformerData
        {
            get

            {
                MvpSerializerTransformerData data = base.TransformerData as MvpSerializerTransformerData;
                return data;
            }
        }

        protected override void OnSited()
        {
            base.OnSited();
        }

        protected override void OnAddMenuItems()
        {
            if (!Parent.GetType().Equals(typeof(ReadOnlyConfigurationSectionNode)))
            {
                AddMenuItem(ConfigurationMenuItem.CreateRemoveNodeCommand(Site, this));
            }
            AddMenuItem(ConfigurationMenuItem.CreateValidateNodeCommand(Site, this));
        }
   }
}