using System;
using System.ComponentModel;
using System.Configuration;
using System.Data;
using System.Diagnostics;
using System.Threading;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Storage;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace EnterpriseLibrary.Extensions
{
	public class ConfigurationChangeDatabaseWatcher : ConfigurationChangeWatcher
    {
        private static readonly string eventSourceName = SR.DatabaseWatcherEventSource;
        private RuntimeConfigurationView runtimeConfigurationView;
		private string configurationSectionName;
		private string dbInstance;
		private string getConfig;
		private string setConfig;

		
		public ConfigurationChangeDatabaseWatcher(
								string dbInstance, 
								string getConfig, 
								string setConfig, 
								string configurationSectionName,
								RuntimeConfigurationView runtimeConfigurationView)
			: base()
        {
            this.configurationSectionName = configurationSectionName;
            this.dbInstance =	dbInstance;
			this.getConfig	=	getConfig;
			this.setConfig	=	setConfig;
			this.runtimeConfigurationView = runtimeConfigurationView;
        }

        ~ConfigurationChangeDatabaseWatcher()
        {
            Disposing(false);
        }

        /// <summary>
        /// <para>Gets the name of the configuration section being watched.</para>
        /// </summary>
        /// <value>
        /// <para>The name of the configuration section being watched.</para>
        /// </value>
        public override string SectionName
        {
            get { return configurationSectionName; }
        }

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		protected override DateTime GetCurrentLastWriteTime()
		{
			DateTime currentLastWriteTime = DateTime.MinValue;
			Database db;

			try
			{
				db = DatabaseFactory.CreateDatabase(this.dbInstance);
			}
			// when the Config Console is used to modify this information 
			// the database factory has to be used dynamically build the dbInstance
			catch (ConfigurationException)		
			{
				ConfigurationContext ctx = runtimeConfigurationView.ConfigurationContext;
				try
				{
					DatabaseProviderFactory factory = new DatabaseProviderFactory(ctx);
					db = factory.CreateDatabase(dbInstance);
				}
				catch (Exception e)
				{
					throw new ConfigurationException(SR.ExceptionConfigurationDbInvalidSection(SectionName),e);
				}
			}
			catch (Exception e)
			{
				throw new ConfigurationException(SR.ExceptionConfigurationDbInvalidSection(SectionName),e);
			}

			IDataReader dataReader = db.ExecuteReader(this.getConfig, this.SectionName);
			if( dataReader.Read() )
				currentLastWriteTime = dataReader.IsDBNull( 2 ) ? DateTime.MinValue : dataReader.GetDateTime( 2 );
			dataReader.Close();
			return currentLastWriteTime;
		}

		protected override string BuildThreadName()
		{
			return string.Empty;
		}

		protected override ConfigurationChangedEventArgs BuildEventData()
		{
			return new ConfigurationDatabaseChangedEventArgs(dbInstance,getConfig, setConfig, configurationSectionName);
		}

		protected override string GetEventSourceName()
		{
			return eventSourceName;
		}

   }
}