using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Transformer;
using NUnit.Framework;

namespace EnterpriseLibrary.Extensions.Tests 
{
    [TestFixture]
    public class DatabaseStorageProviderFixture 
    {
        private const string sectionName = "DatabaseTestConfig";
		private const string sectionNameBinary = "DatabaseTestConfigBinary";
		private const string color = "Red";
        private const int size = 5;
        private const string text = "Some random text";

        private ConfigurationData data;
    	       
        [SetUp]
        public void SetUp()
        {
            data = new ConfigurationData();;
            data.Color = color;
            data.Size = size;
            data.SomeText = text;
        }


        [Test]
        public void WriteConfigurationDataTest()
        {
            DatabaseStorageProvider provider = new DatabaseStorageProvider();
            provider.CurrentSectionName = sectionName;
            provider.Initialize(new RuntimeConfigurationView(ConfigurationManager.GetCurrentContext()));
            XmlSerializerTransformer transformer = new XmlSerializerTransformer();
            object serializedData = transformer.Serialize(data);
            provider.Write(serializedData);
            ValidateReadData(provider.CurrentSectionName);
        }

		[Test]
		public void WriteConfigurationDataTestUsingBinaryTransformer()
		{
			DatabaseStorageProvider provider = new DatabaseStorageProvider();
			provider.CurrentSectionName = sectionNameBinary;
			provider.Initialize(new RuntimeConfigurationView(ConfigurationManager.GetCurrentContext()));
			BinaryTranformer transformer = new BinaryTranformer();
			object serializedData = transformer.Serialize(data);
			provider.Write(serializedData);
			ValidateReadData(provider.CurrentSectionName);
		}
    	
    	private void ValidateReadData(string sectionName)
        {
            ConfigurationData readData = (ConfigurationData)ConfigurationManager.GetConfiguration(sectionName);
            Assert.IsNotNull(readData);
            Assert.AreEqual(data.Color, readData.Color);
            Assert.AreEqual(data.Size, readData.Size);
            Assert.AreEqual(data.SomeText, readData.SomeText);
        }
    }
}