using System;
using System.Configuration;
using System.Globalization;
using System.IO;
using System.Security.Permissions;
using System.Xml;
using System.Xml.Serialization;
using EnterpriseLibrary.Extensions.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common;
using Microsoft.Practices.EnterpriseLibrary.Configuration;

namespace EnterpriseLibrary.Extensions
{
    [ReflectionPermission(SecurityAction.Demand, MemberAccess=true)]
    public class MvpSerializerTransformer : TransformerProvider
    {
        private XmlSerializer typSerializer;

        public MvpSerializerTransformer()
        {
        }

        public override void Initialize(ConfigurationView configurationView)
        {
            ArgumentValidation.CheckForNullReference(configurationView, "configurationCursor");
            ArgumentValidation.CheckExpectedType(configurationView, typeof(RuntimeConfigurationView));

            RuntimeConfigurationView runtimeConfigurationView = (RuntimeConfigurationView)configurationView;
            TransformerData transformerData = runtimeConfigurationView.GetTransformerProviderData(CurrentSectionName);
			if (transformerData is MvpSerializerTransformerData)
			{
				MvpSerializerTransformerData mvpTransformerData = transformerData as MvpSerializerTransformerData;
				typSerializer = (XmlSerializer)Activator.CreateInstance(Type.GetType(mvpTransformerData.SerializationType));
			}
			else
				throw new ConfigurationException(SR.ExceptionSerializationTypeMissing);
        }

		public XmlSerializer Serializer
		{
			get { return typSerializer; }
		}

        public override object Deserialize(object section)
        {
			ArgumentValidation.CheckForNullReference(section, "section");
			ArgumentValidation.CheckExpectedType(section, typeof(XmlNode));

			XmlNode sectionNode = (XmlNode)section;
			XmlSerializer xs = Serializer;
            try
            {
				XmlNode topNode = sectionNode; 
                return xs.Deserialize(new XmlNodeReader(topNode));
            }
            catch (InvalidOperationException e)
            {
                string message = e.Message;
                if (null != e.InnerException)
                {
                    message = String.Concat(message, " ", e.InnerException.Message);
                }
                throw new ConfigurationException(message, e);
            }

        }

        public override object Serialize(object value)
        {
            XmlSerializer xmlSerializer = Serializer;
            StringWriter stringWriter = new StringWriter(CultureInfo.InvariantCulture);
            XmlTextWriter xmlTextWriter = new XmlTextWriter(stringWriter);
            XmlDocument doc = new XmlDocument();
            try
            {
                xmlSerializer.Serialize(xmlTextWriter, value);
                xmlTextWriter.Flush();
                doc.LoadXml(stringWriter.ToString());
            }
            finally
            {
                xmlTextWriter.Close();
                stringWriter.Close();
            }
            return doc.DocumentElement;
        }
    }
}