using System.ComponentModel;
using System.Diagnostics;
using System.Drawing.Design;
using Microsoft.Practices.EnterpriseLibrary.Caching.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Caching.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design.Validation;
using XmlFileBackingStore.Configuration;

namespace XmlFileBackingStore.Configuration.Design
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class XmlFileCacheStorageNode : CacheStorageNode
	{
		xmlFileCacheStorageData xmlFileCacheStorageData;
		
		public XmlFileCacheStorageNode(): this(new xmlFileCacheStorageData(SR.XmlFileCacheStorage))
		{
		}

		/// <summary>
		/// Creates node with specified data.
		/// </summary>
		/// <param name="xmlFileCacheStorageData">Configuration data.</param>
		public XmlFileCacheStorageNode(xmlFileCacheStorageData xmlFileCacheStorageData) : base(xmlFileCacheStorageData)
		{
			this.xmlFileCacheStorageData = xmlFileCacheStorageData;
		}

		/// <summary>
		/// Read only.  Returns the type name for a XmlFileBackingStore.
		/// </summary>
		[Browsable(false)]
		public override string Type
		{
			get { return xmlFileCacheStorageData.TypeName; }
		}
		
		/// <summary>
		/// The configured XML File Name.
		/// </summary>
		[Required]
		[SRDescription(SR.Keys.FileNameDescription)]
		[SRCategory(SR.Keys.CategoryGeneral)]
		public string FileName
		{
			get { return xmlFileCacheStorageData.XmlFileName; }
			set { xmlFileCacheStorageData.XmlFileName = value; }
		}

		/// <summary>
		/// The name of the segments in the caching store to use for this data.
		/// </summary>
		[Required]
		[SRDescription(SR.Keys.FilePartitionNameDesciption)]
		[SRCategory(SR.Keys.CategoryGeneral)]
		public string PartitionName
		{
			get { return xmlFileCacheStorageData.PartitionName; }
			set { xmlFileCacheStorageData.PartitionName = value; }
		}

		/// <summary>
		/// Retrieves configuration data based on the current state of the node.
		/// </summary>
		/// <returns>Configuration data for this node.</returns>
		public override CacheStorageData CacheStorageData
		{
			get
			{
				return base.CacheStorageData;
			}
		}


	}
}
