using System;
using System.Diagnostics;
using Microsoft.Practices.EnterpriseLibrary.Caching.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;

namespace XmlFileBackingStore.Configuration.Design
{
	/// <summary>
	/// Summary description for xmlFileBackingStoreConfigurationDesignManager.
	/// </summary>
	public class xmlFileBackingStoreConfigurationDesignManager : IConfigurationDesignManager
	{
		public xmlFileBackingStoreConfigurationDesignManager()
		{
			//
			// TODO: Add constructor logic here
			//
		}

		/// <summary>
		/// <para>Registers the <see cref="xmlFileCacheStorageNode"/> in the application.</para>
		/// </summary>
		/// <param name="serviceProvider">
		/// <para>The a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.</para>
		/// </param>
		public void Register(IServiceProvider serviceProvider)
		{
			RegisterNodeTypes(serviceProvider);
			RegisterXmlIncludeTypes(serviceProvider);
		}

		/// <summary>
		/// <para>Opens the configuration settings and registers them with the application.</para>
		/// </summary>
		/// <param name="serviceProvider">
		/// <para>The a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.</para>
		/// </param>
		public void Open(IServiceProvider serviceProvider)
		{
		}

		/// <summary>
		/// <para>Saves the configuration settings created for the application.</para>
		/// </summary>
		/// <param name="serviceProvider">
		/// <para>The a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.</para>
		/// </param>
		public void Save(IServiceProvider serviceProvider)
		{
		}

		/// <summary>
		/// <para>Adds to the dictionary configuration data for 
		/// the enterpriselibrary.configurationSettings configuration section.</para>
		/// </summary>
		/// <param name="serviceProvider">
		/// <para>The a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.</para>
		/// </param>
		/// <param name="configurationDictionary">
		/// <para>A <see cref="ConfigurationDictionary"/> to add 
		/// configuration data to.</para></param>
		public void BuildContext(IServiceProvider serviceProvider, ConfigurationDictionary configurationDictionary)
		{
		}

		private static void RegisterXmlIncludeTypes(IServiceProvider serviceProvider)
		{
			IXmlIncludeTypeService xmlIncludeTypeService = serviceProvider.GetService(typeof(IXmlIncludeTypeService)) as IXmlIncludeTypeService;
			Debug.Assert(xmlIncludeTypeService != null, "Could not find the IXmlIncludeTypeService");
			xmlIncludeTypeService.AddXmlIncludeType(CacheManagerSettings.SectionName, typeof(xmlFileCacheStorageData));
		}

		private static void RegisterNodeTypes(IServiceProvider serviceProvider)
		{
			INodeCreationService nodeCreationService = ServiceHelper.GetNodeCreationService(serviceProvider);

			Type nodeType = typeof(XmlFileCacheStorageNode);
			NodeCreationEntry entry = NodeCreationEntry.CreateNodeCreationEntryNoMultiples(new AddChildNodeCommand(serviceProvider, nodeType), nodeType, typeof(xmlFileCacheStorageData), SR.XmlFileCacheStorage);
			nodeCreationService.AddNodeCreationEntry(entry);
		}
	}
}