using System;
using System.Xml.Serialization;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling.Configuration;

namespace ExtendedExceptionHandling
{
	/// <summary>
	/// Summary description for ContextualWrapData.
	/// </summary>
	[XmlRoot("exceptionHandler", Namespace=ExceptionHandlingSettings.ConfigurationNamespace)]
	public class ContextualWrapData : WrapHandlerData
	{
		/// <summary>
		/// Initialize a new instance of the <see cref="ContextualWrapData"/> class.
		/// </summary>
		public ContextualWrapData()
		{
		}

		/// <summary>
		/// Initialize a new instance of the <see cref="ContextualWrapData"/> class with a name.
		/// </summary>
		/// <param name="name">
		/// The name of the <see cref="ContextualWrapData"/>.
		/// </param>
		public ContextualWrapData(string name) : base(name)
	{
	}

		/// <summary>
		/// Initialize a new instance of the <see cref="ContextualWrapData"/> class with a name, an exception message, the fully qualified assembly name of type of the wrapping exception.
		/// </summary>
		/// <param name="name">
		/// The name of the <see cref="ContextualWrapData"/>.
		/// </param>
		/// <param name="exceptionMessage">
		/// The exception message replacement.
		/// </param>
		/// <param name="wrapExceptionTypeName">
		/// The fully qualified assembly name of type of the wrapping exception
		/// </param>
		public ContextualWrapData(string name, string exceptionMessage, string wrapExceptionTypeName) : base(name, exceptionMessage,wrapExceptionTypeName)
		{
		}

		/// <summary>
		/// Gets or sets optional for a default exception message replacement.
		/// </summary>
		[XmlAttribute("defaultExceptionMessage")]
		public string DefaultExceptionMessage
		{
			get { return base.ExceptionMessage; }
			set { base.ExceptionMessage = value; }
		}

		[XmlIgnore]
		public override string TypeName
		{
			get { return typeof(ContextualWrapHandler).AssemblyQualifiedName; }
			set
			{
			}
		}
	}
}
