using System;
using System.ComponentModel;
using System.Drawing.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design.Validation;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling.Configuration.Design;
using ExtendedExceptionHandling.Configuration;


namespace ExtendedExceptionHandling.Configuration.Design
{
    /// <summary>
    /// Represents a node for the specific ExceptionHandler "WrapHandler"
    /// </summary>
    public class ContextualWrapHandlerNode : ExceptionHandlerNode, ITypeDependentExceptionHandler
    {
        private ContextualWrapData wrapHandlerData;

        /// <summary>
        /// Constructs node with default values.
        /// </summary>
        public ContextualWrapHandlerNode() : this(new ContextualWrapData(SR.WrapHandlerNodeName, string.Empty, string.Empty))
        {
        }

        /// <summary>
        /// Constructs the node with config data.
        /// </summary>
        /// <param name="wrapHandlerData">The config data to initialize this node.</param>
        public ContextualWrapHandlerNode(ContextualWrapData wrapHandlerData) : base(wrapHandlerData)
        {
            this.wrapHandlerData = wrapHandlerData;
        }

        /// <summary>
        /// The message for the Replace Exception
        /// </summary>
        [SRDescription(SR.Keys.WrapHandlerNodeMessageDescription)]
        [SRCategory(SR.Keys.CategoryGeneral)]
        public string DefaultExceptionMessage
        {
            get { return wrapHandlerData.DefaultExceptionMessage; }
            set { wrapHandlerData.DefaultExceptionMessage = value; }
        }

        /// <summary>
        /// The fully qualified name of the <see cref="WrapHandler"/>.
        /// </summary>
        [Browsable(false)]
        public override string TypeName
        {
            get { return base.TypeName; }
            set { base.TypeName = value; }
        }

        /// <summary>
        /// The fully qualified name of the wrapping exception.
        /// </summary>
        [Required]
        [Editor(typeof(TypeSelectorEditor), typeof(UITypeEditor))]
        [BaseType(typeof(Exception), TypeSelectorIncludeFlags.BaseType)]
        [SRDescription(SR.Keys.ExceptionWrapTypeNameDescription)]
        [SRCategory(SR.Keys.CategoryGeneral)]
        public string WrapExceptionTypeName
        {
            get { return wrapHandlerData.WrapExceptionTypeName; }
            set { wrapHandlerData.WrapExceptionTypeName = value; }
        }

        public void SetSelectedType(Type type)
        {
            wrapHandlerData.WrapExceptionTypeName = type.AssemblyQualifiedName;
        }
    }
}