using System.Xml.Serialization;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Distributor;

namespace DatabaseDistributionStrategy.Configuration
{
    /// <summary>
    /// Represents the configuration settings for a MSMQ distribution strategy.
    /// </summary>
    [XmlRoot("distributionStrategy", Namespace=LoggingSettings.ConfigurationNamespace)]
    public class DatabaseDistributionStrategyData : DistributionStrategyData
    {
        private string storedProc;
		private string databaseInstance;

        /// <summary>
        /// Create a new instance of a <see cref="DatabaseDistributionStrategyData"/>.
        /// </summary>
        public DatabaseDistributionStrategyData() : this(string.Empty, string.Empty)
        {
        }

        /// <summary>
        /// Initialize a new instance of the <see cref="DatabaseDistributionStrategyData"/> class with a name and queue path.
        /// </summary>
        /// <param name="name">
        /// The name of of the strategy.
        /// </param>
        /// <param name="storedProc">
        /// The Stored procedure name.
        /// </param>
        public DatabaseDistributionStrategyData(string name, string storedProc) : this (name, storedProc, string.Empty)
        {
        }


		/// <summary>
		/// Initialize a new instance of the <see cref="DatabaseDistributionStrategyData"/> class with a name and queue path.
		/// </summary>
		/// <param name="name">
		/// The name of of the strategy.
		/// </param>
		/// <param name="storedProc">
		/// The Stored procedure name.
		/// </param>
		/// <param name="databaseInstance">
		/// The Database Instance name.
		/// </param>
		public DatabaseDistributionStrategyData(string name, string storedProc, string databaseInstance) : base(name)
		{
			this.StoredProcedure = storedProc;
			this.DatabaseInstance = databaseInstance;
		}
		
		/// <summary>
        /// The Stored procedure name.
        /// </summary>
        [XmlAttribute("storedProc")]
        public string StoredProcedure
        {
            get { return storedProc; }
            set { storedProc = value; }
        }
		/// <summary>
		/// The Database Instance name.
		/// </summary>
		[XmlAttribute("databaseInstance")]
		public string DatabaseInstance
		{
			get { return databaseInstance; }
			set { databaseInstance = value; }
		}

        /// <summary>
        /// Returns the fully qualified assembly name of a <c>DatabaseDistributionStrategyData</c>.
        /// </summary>
        [XmlIgnore]
        public override string TypeName
        {
            get { return typeof(DatabaseDistributionStrategy).AssemblyQualifiedName; }
            set
            {
            }
        }

    }
}