using System;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration.Design.Client;
using DatabaseDistributionStrategy.Configuration;

namespace DatabaseDistributionStrategy.Design
{
	/// <summary>
	/// Summary description for DatabaseDistributionStrategyDesignManager.
	/// </summary>
	public class DatabaseDistributionStrategyDesignManager : ClientLoggingConfigurationDesignManager
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="ConfigurationDesignManager"/> class.
		/// </summary>
		public DatabaseDistributionStrategyDesignManager()
		{
		}

		/// <summary>
		/// <para>Registers the <see cref="DatabaseDistributionStrategyNode"/> in the application.</para>
		/// </summary>
		/// <param name="serviceProvider">
		/// <para>The a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.</para>
		/// </param>
		public override void Register(IServiceProvider serviceProvider)
		{
			RegisterNodeTypes(serviceProvider);
			RegisterXmlIncludeTypes(serviceProvider);
		}

		public override void Open(IServiceProvider serviceProvider)
		{
		}

		public override void Save(IServiceProvider serviceProvider)
		{
		}

		private static void RegisterXmlIncludeTypes(IServiceProvider serviceProvider)
		{
			IXmlIncludeTypeService xmlIncludeTypeService = ServiceHelper.GetXmlIncludeTypeService(serviceProvider);
            
			xmlIncludeTypeService.AddXmlIncludeType(LoggingSettings.SectionName, typeof(DatabaseDistributionStrategyData));
		}

		private static void RegisterNodeTypes(IServiceProvider serviceProvider)
		{
			INodeCreationService nodeCreationService = ServiceHelper.GetNodeCreationService(serviceProvider);

			Type nodeType = typeof(DatabaseDistributionStrategyNode);
			NodeCreationEntry entry = NodeCreationEntry.CreateNodeCreationEntryWithMultiples(new AddChildNodeCommand(serviceProvider, nodeType), nodeType, typeof(DatabaseDistributionStrategyData), SR.DatabaseDistributionStrategyNode);
			nodeCreationService.AddNodeCreationEntry(entry);
		}

	}
}