#if  UNIT_TESTS
using System;
using System.IO;
using System.Text;
using System.Collections;
using System.Runtime.Serialization.Formatters.Soap;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data;
using Microsoft.Practices.EnterpriseLibrary.Data.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Logging.ExtraInformation;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Tests;
using DatabaseDistributionStrategy.Configuration;
using NUnit.Framework;

namespace DatabaseDistributionStrategy.Tests
{
    [TestFixture]
    public class DatabaseDistributionStrategyFixture
    {
	
		private DatabaseDistributionStrategy databaseStrategy;

		protected static LogEntry GetLogEntry()
		{
			LogEntry entry = new LogEntry(
				"My message body",
				"foo",
				-1,
				1,
				Severity.Unspecified,
				"=== TITLE ===",
				null
				);

			entry.Priority = 100;

			entry.TimeStamp = DateTime.MaxValue;
			entry.MachineName = "machine";

			return entry;
		}

		protected string SerializeEntry(LogEntry entry)
		{
			SoapFormatter formatter = new SoapFormatter();
			string serializedEntry = String.Empty;
			using (MemoryStream ms = new MemoryStream())
			{
				formatter.Serialize(ms, entry);
				ms.Position = 0;
				byte[] buffer = new byte[ms.Length];
				ms.Read(buffer, 0, (int) ms.Length);
				serializedEntry = Encoding.UTF8.GetString(buffer);
			}
			return serializedEntry;
		}

		protected LogEntry DeserializeEntry(string logEntryString)
		{
			byte[] buffer = Encoding.UTF8.GetBytes(logEntryString);
			LogEntry logEntry;
			using (MemoryStream ms = new MemoryStream(buffer))
			{
				SoapFormatter formatter = new SoapFormatter();
				logEntry = (LogEntry)formatter.Deserialize(ms);
			}
			return logEntry;
		}
		
		protected virtual void ClearLogs()
		{
			DatabaseSettings dbSettings = TestConfigurationContext.GenerateDataSettings();
			DatabaseProviderFactory factory = new DatabaseProviderFactory(new TestConfigurationContext());
			Database db = factory.CreateDefaultDatabase();
			db.ExecuteNonQuery("ClearLogs");
		}

		protected string GetLastLogEntry()
		{
			DatabaseSettings dbSettings = TestConfigurationContext.GenerateDataSettings();
			DatabaseProviderFactory factory = new DatabaseProviderFactory(new TestConfigurationContext());
			Database db = factory.CreateDefaultDatabase();
			string retString = Convert.ToString(db.ExecuteScalar(System.Data.CommandType.Text, "SELECT TOP 1 LogEntry FROM LogEntries"));
			return retString;
		}

        [SetUp]
        public void SetUp()
        {
            ClearLogs();

			TestConfigurationContext context = new TestConfigurationContext();
			
			databaseStrategy = new DatabaseDistributionStrategy();
			databaseStrategy.ConfigurationName = "Database";
			databaseStrategy.Initialize(new LoggingConfigurationView(context));
        }

        [TearDown]
        public void TearDown()
        {
            ClearLogs();
        }

        [Test]
        public void DatabaseDistStrategyConstructor()
        {
            Assert.IsNotNull(databaseStrategy);
        }

        [Test]
        public void SerializeMessageToDatabase()
        {
            LogEntry logEntry = GetLogEntry();
			
			databaseStrategy.SendLog(logEntry);

            string actual = GetLastLogEntry();

			Assert.AreEqual(actual,SerializeEntry(logEntry));
        }

        [Test]
        public void SerializeDictionaryToDatabase()
        {
			Hashtable dictionary = new Hashtable();
			DebugInformationProvider provider = new DebugInformationProvider();
			provider.PopulateDictionary(dictionary);

			LogEntry logEntry = GetLogEntry();
			logEntry.Category = "foo";
            logEntry.ExtendedProperties = dictionary;

			databaseStrategy.SendLog(logEntry);

            string actual = GetLastLogEntry();

			Assert.AreEqual(actual,SerializeEntry(logEntry));

			LogEntry deserializedEntry = DeserializeEntry(actual);

            Assert.IsTrue(actual.IndexOf(deserializedEntry.Message) > 0);
            Assert.IsTrue(actual.IndexOf(deserializedEntry.ExtendedProperties["StackTrace"].ToString()) > 0);
        }
		
    }
}

#endif