#if  UNIT_TESTS

using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data.Sql;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Distributor.Configuration;
using DatabaseDistributionStrategy;
using DatabaseDistributionStrategy.Configuration;

namespace DatabaseDistributionStrategy.Tests
{
	public class TestConfigurationContext : ConfigurationContext
	{
		private static ConfigurationDictionary dictionary;

		public TestConfigurationContext()
			: base(GenerateConfigurationDictionary())
		{
		}

		private static ConfigurationDictionary GenerateConfigurationDictionary()
		{
			if (dictionary == null)
			{
				dictionary = new ConfigurationDictionary();
				dictionary.Add(ConfigurationSettings.SectionName, GenerateConfigurationSettings());
				dictionary.Add(DatabaseSettings.SectionName, GenerateDataSettings());
				dictionary.Add(LoggingSettings.SectionName, GenerateLoggingSettings());
				dictionary.Add(DistributorSettings.SectionName, GenerateDistributorSettings());
			}
			return dictionary;
		}

		private static ConfigurationSettings GenerateConfigurationSettings()
		{
			ConfigurationSettings settings = new ConfigurationSettings();
			settings.ConfigurationSections.Add(new ConfigurationSectionData(DatabaseSettings.SectionName, false, new XmlFileStorageProviderData("XmlStorage", "EnterpriseLibrary.Data.config"), new XmlSerializerTransformerData("DataBuilder")));
			settings.ConfigurationSections.Add(new ConfigurationSectionData(LoggingSettings.SectionName, false, new XmlFileStorageProviderData("XmlStorage", "EnterpriseLibrary.Logging.config"), new XmlSerializerTransformerData("DataBuilder")));
			settings.ConfigurationSections.Add(new ConfigurationSectionData(DistributorSettings.SectionName, false, new XmlFileStorageProviderData("XmlStorage", "EnterpriseLibrary.LoggingDistributor.config"), new XmlSerializerTransformerData("DataBuilder")));
			return settings;
		}

		public static DatabaseSettings GenerateDataSettings()
		{
			DatabaseSettings settings = new DatabaseSettings();

			settings.DefaultInstance = "LogDistributor";

			settings.DatabaseTypes.Add(new DatabaseTypeData("SqlServer", typeof(SqlDatabase).AssemblyQualifiedName));

			ConnectionStringData data = new ConnectionStringData("LoggingConnStr");
			data.Parameters.Add(new ParameterData("server", "(local)"));
			data.Parameters.Add(new ParameterData("database", "LogDistributor"));
			data.Parameters.Add(new ParameterData("Integrated Security", "true"));
			settings.ConnectionStrings.Add(data);

			settings.Instances.Add(new InstanceData("LogDistributor", "SqlServer", "LoggingConnStr"));

			return settings;
		}

		private static LoggingSettings GenerateLoggingSettings()
		{
			LoggingSettings result = new LoggingSettings();

			result.LoggingEnabled = true;
			result.TracingEnabled = true;
			result.MinimumPriority = 5;
			result.DistributionStrategy = "Database";
			result.CategoryFilterMode = CategoryFilterMode.AllowAllExceptDenied;

			DatabaseDistributionStrategyData data = new DatabaseDistributionStrategyData("Database", "WriteLogEntry", "LogDistributor");
			result.DistributionStrategies.Add(data);

			return result;
		}

		private static DistributorSettings GenerateDistributorSettings()
		{
			DistributorSettings result = new DistributorSettings();			
			
			result.DefaultCategory="AppError" ;
			result.DefaultFormatter="XmlFormat";

			result.DistributorService = new MsmqDistributorServiceData("Enterprise Library Logging Distributor Service", @".\Private$\entlib", 1000 );

			//result.SinkDataCollection.Add( new CustomSinkData("MockSink", typeof(MockLogSink).AssemblyQualifiedName ) );

			result.Formatters.Add( new TextFormatterData("XmlFormat", "<![CDATA[<EntLibLog>{newline}{tab}<message>{message}</message>{newline}{tab}<timestamp>{timestamp}</timestamp>{newline}{tab}<title>{title}</title>{newline}</EntLibLog>]]>"));

			CategoryData data = new CategoryData();
			data.Name = "AppError";
			data.DestinationDataCollection.Add( new DestinationData("MockSink", "MockSink"));
			result.CategoryDataCollection.Add(data);

			return result;
		}
	}
}
#endif
