using System.Xml.Serialization;

namespace Microsoft.Practices.EnterpriseLibrary.Logging.Distributor.Configuration
{
    /// <summary>
    /// Configuration data for the Msmq Distributor Service
    /// </summary>
    [XmlRoot("distributorService", Namespace=DistributorSettings.ConfigurationNamespace)]
    public class DatabaseDistributorServiceData
    {
        private string serviceName;
		private string databaseInstanceName;
        private string getStoredProcName;
        private int pollingInterval;

        /// <summary>
        /// Creates a new instance of the <see cref="DatabaseDistributorServiceData"/> class using default values.
        /// </summary>
        public DatabaseDistributorServiceData()
        {
        }

        /// <summary>
        /// Creates a new instance of the <see cref="DatabaseDistributorServiceData"/> class using 
        /// the given service name, databaseInstance name, stored procedure and polling interval.
        /// </summary>
        /// <param name="serviceName">The name of the service.</param>
        /// <param name="msmqPath">The MSMQ Path to use.</param>
        /// <param name="queueTimerInterval">The queue timer interval.</param>
        public DatabaseDistributorServiceData(string serviceName, string databaseInstanceName, string getStoredProcName, int pollingInterval)
        {
            this.serviceName = serviceName;
            this.databaseInstanceName = databaseInstanceName;
            this.getStoredProcName = getStoredProcName;
            this.pollingInterval = pollingInterval;
        }

        /// <summary>
        /// Name of the Database distributor windows service.
        /// </summary>
        [XmlAttribute("serviceName")]
        public string ServiceName
        {
            get { return this.serviceName; }
            set { this.serviceName = value; }
        }

        /// <summary>
        /// Database Instance used by the Database distributor windows service.
        /// </summary>
        [XmlAttribute("databaseInstanceName")]
        public string DatabaseInstanceName
        {
            get { return this.databaseInstanceName; }
            set { this.databaseInstanceName = value; }
        }

		/// <summary>
		/// Database Instance used by the Database distributor windows service.
		/// </summary>
		[XmlAttribute("getStoredProcName")]
		public string StoredProcName
		{
			get { return this.getStoredProcName; }
			set { this.getStoredProcName = value; }
		}

		/// <summary>
        /// Timer interval to poll the message queue in the MSMQ distributor windows service.
        /// </summary>
        [XmlAttribute("pollingInterval")]
        public int PollingInterval
        {
            get { return this.pollingInterval; }
            set { this.pollingInterval = value; }
        }
    }
}