using System;
using System.Xml.Serialization;

namespace DatabaseDistributor.Configuration
{
    /// <summary>
    /// <para>Represents the root configuration for data.</para>
    /// </summary>
    /// <remarks>
    /// <para>The class maps to the <c>DatabaseDistributorSettings</c> element in configuration.</para>
    /// </remarks>
	[CLSCompliantAttribute(true)]
	[XmlRoot("enterpriseLibrary.databaseDistributorSettings")]
    public class DatabaseDistributorSettings
    {
		private string serviceName;
		private string databaseInstanceName;
		private string getStoredProcName;
		private int pollingInterval;
		
		/// <summary>
        /// The name of the database distributor configuration section.
        /// </summary>
        public const string SectionName = "databaseDistributorConfiguration";

        /// <summary>
        /// <para>Gets the Xml namespace for this root node.</para>
        /// </summary>
        /// <value>
        /// <para>The Xml namespace for this root node.</para>
        /// </value>
        public const string ConfigurationNamespace = "http://www.microsoft.com/practices/enterpriselibrary/08-31-2004/dbdistributor";

        /// <summary>
        /// <para>Initialize a new instance of the <see cref="DatabaseSettings"/> class.</para>
        /// </summary>
        public DatabaseDistributorSettings()
        {
        }

		/// <summary>
		/// Creates a new instance of the <see cref="DatabaseDistributorServiceData"/> class using 
		/// the given service name, databaseInstance name, stored procedure and polling interval.
		/// </summary>
		/// <param name="serviceName">The name of the service.</param>
		/// <param name="getStoredProcName">The stored proc to use to get the data.</param>
		public DatabaseDistributorSettings(string serviceName, string getStoredProcName) : this(serviceName, null, getStoredProcName, 1000)
		{
		}

		
		/// <summary>
		/// Creates a new instance of the <see cref="DatabaseDistributorServiceData"/> class using 
		/// the given service name, databaseInstance name, stored procedure and polling interval.
		/// </summary>
		/// <param name="serviceName">The name of the service.</param>
		/// <param name="databaseInstanceName">The database instance to use.</param>
		/// <param name="getStoredProcName">The stored proc to use to get the data.</param>
		/// <param name="queueTimerInterval">The polling interval.</param>
		public DatabaseDistributorSettings(string serviceName, string databaseInstanceName, string getStoredProcName, int pollingInterval)
		{
			this.serviceName = serviceName;
			this.databaseInstanceName = databaseInstanceName;
			this.getStoredProcName = getStoredProcName;
			this.pollingInterval = pollingInterval;
		}

		/// <summary>
		/// Name of the Database distributor windows service.
		/// </summary>
		[XmlAttribute("serviceName")]
		public string ServiceName
		{
			get { return this.serviceName; }
			set { this.serviceName = value; }
		}

		/// <summary>
		/// Database Instance used by the Database distributor windows service.
		/// </summary>
		[XmlAttribute("databaseInstanceName")]
		public string DatabaseInstanceName
		{
			get { return this.databaseInstanceName; }
			set { this.databaseInstanceName = value; }
		}

		/// <summary>
		/// Database Instance used by the Database distributor windows service.
		/// </summary>
		[XmlAttribute("getStoredProcName")]
		public string StoredProcName
		{
			get { return this.getStoredProcName; }
			set { this.getStoredProcName = value; }
		}

		/// <summary>
		/// Timer interval to poll the database in the database distributor windows service.
		/// </summary>
		[XmlAttribute("pollingInterval")]
		public int PollingInterval
		{
			get { return this.pollingInterval; }
			set { this.pollingInterval = value; }
		}
	}
}