using System;
using System.Collections;
using System.Globalization;
using System.IO;
using System.Xml;
using System.Reflection;
using System.Xml.Serialization;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Transformer;

namespace Microsoft.Practices.EnterpriseLibrary.Logging.ExtraInformation 
{
	/// <summary>
	/// Summary description for ELConfigurationContextProvider.
	/// </summary>
	public class ELConfigurationContextInformationProvider : IExtraInformationProvider
	{
		public void PopulateDictionary(IDictionary dict)
		{
			ConfigurationContext context = ConfigurationManager.GetCurrentContext();
			ConfigurationSettings configSettings = context.GetMetaConfiguration();
			
			dict.Add("ApplicationName",configSettings.ApplicationName);
			foreach (ConfigurationSectionData configSection in configSettings.ConfigurationSections)
			{
				string sectionName = configSection.Name;

				//I dont want to just GetConfiguration b/c then I would be deserializing just to reserialize again.
				//I want to just use the storageprovider to get the serialized object
				Type typStorageProvider = Type.GetType(configSection.StorageProvider.TypeName);
				ConstructorInfo constructor = typStorageProvider.GetConstructor(new Type[] {});
				object createdObject = constructor.Invoke(null);
				IStorageProviderReader storageProviderReader = (IStorageProviderReader) createdObject;
				RuntimeConfigurationView view = new RuntimeConfigurationView(context);
				storageProviderReader.ConfigurationName = configSection.StorageProvider.Name;
				storageProviderReader.CurrentSectionName = sectionName;
				storageProviderReader.Initialize(view);
 				object configSectionSettings = storageProviderReader.Read();
	
				//I need to tell it how I want the value written, so the Serialize method will write out config
				dict.Add(sectionName,Serialize(configSectionSettings));
			}
		}

		private string Serialize(object value)
		{
			XmlSerializer xmlSerializer = new XmlSerializer(value.GetType());
			StringWriter stringWriter = new StringWriter(CultureInfo.InvariantCulture);
			string strRetString = String.Empty;
			XmlTextWriter xmlTextWriter = new XmlTextWriter(stringWriter);
			XmlDocument doc = new XmlDocument();
			try
			{
				xmlTextWriter.WriteStartElement("xmlSerializerSection");
				xmlTextWriter.WriteAttributeString("type", value.GetType().AssemblyQualifiedName);
				xmlSerializer.Serialize(xmlTextWriter, value);
				xmlTextWriter.WriteEndElement();
				xmlTextWriter.Flush();
				strRetString = stringWriter.ToString();
			}
			finally
			{
				xmlTextWriter.Close();
				stringWriter.Close();
			}
			return strRetString;
		}

 	}
}
