using System.Collections;
using System.Text;

namespace Microsoft.Practices.EnterpriseLibrary.Logging.Formatters
{
    /// <summary>
    /// Formats a dictionary token by iterating through the dictionary and displays 
    /// the key and value for each entry.
    /// </summary>
    public class ELDictionaryToken : DictionaryToken
    {
        private string startDelimiter = "{dictionary(";
		private const string DictionaryKeyToken = "{key}";
        private const string DictionaryValueToken = "{value}";
		private string endDelimiter = ")}";

        /// <summary>
        /// Initialize a new instance of a <see cref="DictionaryToken"/>.
        /// </summary>
        public ELDictionaryToken() : base() //("{dictionary(")
        {
        }

		/// <summary>
		/// Search for token functions in the message and replace all with formatted values.
		/// </summary>
		/// <param name="messageBuilder">Message template containing tokens.</param>
		/// <param name="log">Log entry containing properties to format.</param>
		public override void Format(StringBuilder messageBuilder, LogEntry log)
		{
			if (this.startDelimiter.Length == 0)
			{
				return;
			}

			int pos = 0;
			while (pos < messageBuilder.Length)
			{
				string messageString = messageBuilder.ToString();
				if (messageString.IndexOf(this.startDelimiter) == -1)
				{
					break;
				}

				string tokenTemplate = GetInnerTemplate(pos, messageString);
				string tokenToReplace = this.startDelimiter + tokenTemplate + this.endDelimiter;
				pos = messageBuilder.ToString().IndexOf(tokenToReplace);

				string tokenValue = FormatToken(tokenTemplate, log);

				messageBuilder.Replace(tokenToReplace, tokenValue);

				//skip past the token we just entered so we don't get into an infinite loop if the token is part of the value
				pos += tokenValue.Length;
			}
		}
		
		
		/// <summary>
        /// Iterate through each entry in the dictionary and display the key and/or value.
        /// </summary>
        /// <param name="tokenTemplate">Template to repeat for each key/value pair.</param>
        /// <param name="log">Log entry containing the extended properties dictionary.</param>
        /// <returns>Repeated template for each key/value pair.</returns>
//        public override string FormatToken(string tokenTemplate, LogEntry log)
//        {
//            if (log.ExtendedProperties == null)
//            {
//                return "";
//            }
//
//            StringBuilder dictionaryBuilder = new StringBuilder();
//            foreach (DictionaryEntry entry in log.ExtendedProperties)
//            {
//                StringBuilder singlePair = new StringBuilder(tokenTemplate);
//                string keyName = "";
//                if (entry.Key != null)
//                {
//                    keyName = entry.Key.ToString();
//                }
//                singlePair.Replace(DictionaryKeyToken, keyName);
//
//                string keyValue = "";
//                if (entry.Value != null)
//                {
//                    keyValue = entry.Value.ToString();
//                }
//                singlePair.Replace(DictionaryValueToken, keyValue);
//
//                dictionaryBuilder.Append(singlePair.ToString());
//            }
//
//            return dictionaryBuilder.ToString();
//        }
    }
}