using System.Xml.Serialization;
using Microsoft.Practices.EnterpriseLibrary.Logging.Distributor.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Sinks;

namespace Logging.DebugSink.Configuration
{
    /// <summary>
    /// Represents the configuration settings for an <see cref="DebugSink"/>.
    /// </summary>
    [XmlRoot("sink", Namespace=DistributorSettings.ConfigurationNamespace)]
    public class DebugSinkData : SinkData
    {
        private string header = string.Empty;
        private string footer = string.Empty;

        /// <summary>
        /// Create a new instance of a <see cref="DebugSinkData"/>.
        /// </summary>
        public DebugSinkData()
        {
        }

        /// <summary>
        /// Initialize a new instance of the <see cref="DebugSinkData"/> class with a name.
        /// </summary>
        /// <param name="name">
        /// The name of the sink.
        /// </param>
        public DebugSinkData(string name) : this(name, string.Empty, string.Empty)
        {
        }

        /// <summary>
        /// Initialize a new instance of the <see cref="DebugSinkData"/> class with a name.
        /// </summary>
        /// <param name="name">
        /// The name of the sink.
        /// </param>
         /// <param name="header">
        /// Optional header to write before each log message.
        /// </param>
        /// <param name="footer">
        /// Optional footer to write after each log message.
        /// </param>
        public DebugSinkData(string name, string header, string footer) : base(name)
        {
            this.header = header;
            this.footer = footer;
        }

        /// <summary>
        /// Optional header to write before each log message.
        /// </summary>
        [XmlAttribute("header")]
        public string Header
        {
            get { return header; }
            set { header = value; }
        }

        /// <summary>
        /// Optional footer to write after each log message.
        /// </summary>
        [XmlAttribute("footer")]
        public string Footer
        {
            get { return footer; }
            set { footer = value; }
        }

        /// <summary>
        /// Gets the fully qualified assembly name of a <c>FlatFileSink</c>.
        /// </summary>
        [XmlIgnore]
        public override string TypeName
        {
            get { return typeof(DebugSink).AssemblyQualifiedName; }
            set
            {
            }
        }

    }
}