using System;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration.Design.Distributor;
using Microsoft.Practices.EnterpriseLibrary.Logging.Distributor.Configuration;
using Logging.DebugSink.Configuration;

namespace Logging.DebugSink.Design
{
    /// <summary>
    /// Represents the block manager for the DebugSink configuration data.
    /// </summary>
    public class DebugSinkConfigurationDesignManager : DistributorLoggingConfigurationDesignManager
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ConfigurationDesignManager"/> class.
        /// </summary>
        public DebugSinkConfigurationDesignManager()
        {
        }

        /// <summary>
        /// <para>Registers the <see cref="DebugSinkNode"/> in the application.</para>
        /// </summary>
        /// <param name="serviceProvider">
        /// <para>The a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.</para>
        /// </param>
        public override void Register(IServiceProvider serviceProvider)
        {
            RegisterNodeTypes(serviceProvider);
            RegisterXmlIncludeTypes(serviceProvider);
        }

		public override void Open(IServiceProvider serviceProvider)
		{
		}

		public override void Save(IServiceProvider serviceProvider)
		{
		}

		private static void RegisterXmlIncludeTypes(IServiceProvider serviceProvider)
        {
			IXmlIncludeTypeService xmlIncludeTypeService = ServiceHelper.GetXmlIncludeTypeService(serviceProvider);
			xmlIncludeTypeService.AddXmlIncludeType(DistributorSettings.SectionName, typeof(DebugSinkData));
        }

        private static void RegisterNodeTypes(IServiceProvider serviceProvider)
        {
            INodeCreationService nodeCreationService = ServiceHelper.GetNodeCreationService(serviceProvider);

            Type nodeType = typeof(DebugSinkNode);
            NodeCreationEntry entry = NodeCreationEntry.CreateNodeCreationEntryWithMultiples(new AddChildNodeCommand(serviceProvider, nodeType), nodeType, typeof(DebugSinkData), SR.DebugSinkNodeName);
            nodeCreationService.AddNodeCreationEntry(entry);
        }

    }
}