using System.ComponentModel;
using System.Drawing.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design.Validation;
using Microsoft.Practices.EnterpriseLibrary.Logging.Distributor.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging.Configuration.Design.Distributor.Sinks;
using Logging.DebugSink.Configuration;

namespace Logging.DebugSink.Design
{
    /// <summary>
    /// Node representing a debug sink.
    /// </summary>
    public class DebugSinkNode : SinkNode
    {
        private DebugSinkData debugSinkData;

        /// <summary>
        /// Creates node with initial configuration data.
        /// </summary>
        public DebugSinkNode() : this(new DebugSinkData(SR.DebugSink, string.Empty, string.Empty))
        {
        }

        /// <summary>
        /// Creates node with specified configuration data.
        /// </summary>
        /// <param name="debugSinkData">Configuration data.</param>
        public DebugSinkNode(DebugSinkData debugSinkData) : base(debugSinkData)
        {
            this.debugSinkData = debugSinkData;
        }

        /// <summary>
        /// Read only. Returns the type name of a <see cref="DebugSink"/>.
        /// </summary>
        [Browsable(false)]
        public override string TypeName
        {
            get { return debugSinkData.TypeName; }
        }

        /// <summary>
        /// Optional header to write before each log message.
        /// </summary>
        [SRDescription(SR.Keys.DebugSinkHeader)]
        [SRCategory(SR.Keys.CategoryGeneral)]
        public string Header
        {
            get { return debugSinkData.Header; }
            set { debugSinkData.Header = value; }
        }

        /// <summary>
        /// Optional footer to write after each log message.
        /// </summary>
        [SRDescription(SR.Keys.DebugSinkFooter)]
        [SRCategory(SR.Keys.CategoryGeneral)]
        public string Footer
        {
            get { return debugSinkData.Footer; }
            set { debugSinkData.Footer = value; }
        }
    }
}