using System;
using Microsoft.Practices.EnterpriseLibrary.Common;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Logging.Sinks;
using Microsoft.Practices.EnterpriseLibrary.Logging.Distributor.Configuration;
using Logging.DebugSink.Configuration;

namespace Logging.DebugSink
{
	/// <summary>
	/// Logging sink that writes messages to the Visual Studio debugger output.
	/// </summary>
	public class DebugSink :  LogSink
	{
		private DefaultLogDestination defaultSink = new DefaultLogDestination();
		private DebugSinkData debugSinkData;

	    /// <summary>
		/// Default constructor with empty parameter list for DebugSink objects.
		/// </summary>
		public DebugSink()
		{
		}
		
		public override void Initialize(ConfigurationView configurationView)
		{
			ArgumentValidation.CheckForNullReference(configurationView, "configurationView");
			ArgumentValidation.CheckExpectedType(configurationView, typeof(LoggingConfigurationView));
			
			LoggingConfigurationView loggingConfigurationView = (LoggingConfigurationView)configurationView;
			SinkData sinkData = loggingConfigurationView.GetSinkData(ConfigurationName);
			ArgumentValidation.CheckExpectedType(sinkData, typeof (DebugSinkData));

			debugSinkData = sinkData as DebugSinkData;
		}

		/// <summary>
		/// Writes the log message to the Visual Studio debugger output. 
		/// </summary>
		/// <param name="logEntry">The entry containing the information to be logged.</param>
		protected override void SendMessageCore(LogEntry logEntry)
		{
			try
			{
				if (!debugSinkData.Header.Equals(String.Empty))
					System.Diagnostics.Debug.WriteLine(debugSinkData.Header);

				System.Diagnostics.Debug.WriteLine(FormatEntry(logEntry));
				
				if (!debugSinkData.Footer.Equals(String.Empty))
					System.Diagnostics.Debug.WriteLine(debugSinkData.Footer);
			}
			catch (Exception e)
			{
				logEntry.AddErrorMessage(SR.SinkFailureMessage(e.ToString()));
				this.defaultSink.SendMessage(logEntry);
			}
		}
	}
}
