#if  UNIT_TESTS
using System.Configuration;
using System.Security.Principal;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.Security;
using Authentication.Providers.ADAuthenticationProvider;
using NUnit.Framework;

namespace Authentication.Providers.ADAuthenticationProvider.Tests
{
    [TestFixture]
    public class ADAuthenticationProviderFixture 
    {
        private static  ADAuthenticationProvider ADAuthProvider;
        private byte[] password;
        private static string userName;

        [SetUp]
        public void SetUp()
        {
            ADAuthProvider = (ADAuthenticationProvider)AuthenticationFactory.GetAuthenticationProvider();
            password = ASCIIEncoding.ASCII.GetBytes(ENTER PASSWORD HERE);
            userName = @"ENTER USER NAME";
        }

        [TearDown]
        public void TearDown()
        {
            ADAuthProvider = null;
        }

        [Test]
        public void CheckThatProviderFactoryCreatesConfiguredInstance()
        {
            ADAuthProvider = (ADAuthenticationProvider)AuthenticationFactory.GetAuthenticationProvider();

            Assert.IsNotNull(ADAuthProvider);
            Assert.AreEqual("Authentication.Providers.ADAuthenticationProvider.ADAuthenticationProvider", ADAuthProvider.ToString());
        }

        [Test]
		[ExpectedException(typeof(ConfigurationException))]
        public void CheckThatProviderFactoryDoesNotInitializeInvalidInstance()
        {
            AuthenticationFactory.GetAuthenticationProvider("NonConfiguredDbAuthenticationProviderName");
        }

        [Test]
        public void CheckIfAuthenticationSucceedsWithValidCredentials()
        {
            NamePasswordCredential credentials = new NamePasswordCredential(userName, password);
            IIdentity identity;

            bool retVal = ADAuthProvider.Authenticate(credentials, out identity);

            Assert.IsTrue(retVal);
            Assert.IsNotNull(identity);
            Assert.AreEqual(userName, identity.Name);
            Assert.IsTrue(identity.IsAuthenticated);
        }
//
//        [Test]
//        public void AuthenticationSucceedsWithZeroLengthPassword()
//        {
//            NamePasswordCredential credentials = new NamePasswordCredential("emptyUser", new byte[] {});
//            IIdentity identity;
//
//            bool successfulAuthentication = dbAuthProvider.Authenticate(credentials, out identity);
//            Assert.IsTrue(successfulAuthentication);
//            Assert.IsTrue(identity.IsAuthenticated);
//        }
//
//        [Test]
//        public void AuthenticationCanBeSuccessfulTwice()
//        {
//            NamePasswordCredential credentials = new NamePasswordCredential(username, password);
//            IIdentity firstIdentity;
//            bool firstCall = dbAuthProvider.Authenticate(credentials, out firstIdentity);
//
//            IIdentity secondIdentity;
//            bool secondCall = dbAuthProvider.Authenticate(credentials, out secondIdentity);
//
//            Assert.IsTrue(firstCall);
//            Assert.IsTrue(secondCall);
//            Assert.IsNotNull(secondIdentity);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationSucceedsWithValidCredentialsThroughInterface()
//        {
//            IAuthenticationProvider IAuthProvider = AuthenticationFactory.GetAuthenticationProvider("DbAuthenticationProviderName");
//
//            NamePasswordCredential credentials = new NamePasswordCredential(username, password);
//            IIdentity identity;
//
//            bool retVal = IAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsTrue(retVal);
//            Assert.IsNotNull(identity);
//            Assert.AreEqual(username, identity.Name);
//            Assert.IsTrue(identity.IsAuthenticated);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationSucceedsWithCredentialsCastToObject()
//        {
//            NamePasswordCredential credentials = new NamePasswordCredential(username, password);
//            IIdentity identity;
//
//            bool retVal = dbAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsTrue(retVal);
//            Assert.IsNotNull(identity);
//            Assert.AreEqual(username, identity.Name);
//            Assert.IsTrue(identity.IsAuthenticated);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationFailsWithBogusCredentialsObject()
//        {
//            string credentials = "TestCredentials";
//            IIdentity identity;
//
//            bool retVal = dbAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsFalse(retVal);
//            Assert.IsNull(identity);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationFailsWithInvalidPassword()
//        {
//            byte[] password = ASCIIEncoding.ASCII.GetBytes("InvalidPassword");
//            NamePasswordCredential credentials = new NamePasswordCredential(username, password);
//            IIdentity identity;
//
//            bool retVal = dbAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsFalse(retVal);
//            Assert.IsNull(identity);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationFailsWithInvalidUsername()
//        {
//            byte[] password = ASCIIEncoding.ASCII.GetBytes("password");
//            NamePasswordCredential credentials = new NamePasswordCredential("invalidUserName", password);
//            IIdentity identity;
//
//            bool retVal = dbAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsFalse(retVal);
//            Assert.IsNull(identity);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationFailsWithNullCredentialObject()
//        {
//            NamePasswordCredential credentials = null;
//            IIdentity identity;
//
//            bool retVal = dbAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsFalse(retVal);
//            Assert.IsNull(identity);
//        }
//
//        [Test]
//        public void CheckIfAuthenticationFailsWithInvalidCredentialObject()
//        {
//            object credentials = new object();
//            IIdentity identity;
//
//            bool retVal = dbAuthProvider.Authenticate(credentials, out identity);
//
//            Assert.IsFalse(retVal);
//            Assert.IsNull(identity);
//        }
    }
}

#endif