using System;
using System.Security;
using System.Security.Permissions;
using System.Security.Principal;
using System.Threading;
using System.IO;
using System.Reflection;

using Microsoft.Practices.EnterpriseLibrary.Security;
using EAF.Security.AuthorizationProviderPermissions;
using NUnit.Framework;

#if  UNIT_TESTS
namespace EAF.Security.AuthorizationProviderPermissionTests
{
	[TestFixture]
	public class AuthorizationProviderPermissionFixture
	{
		[TestFixtureSetUp]
		public void FixtureSetup()
		{
			Thread.CurrentPrincipal = new GenericPrincipal(WindowsIdentity.GetCurrent(), new string[] {"Manager"});
		}

		private void DemandAttribute(SecurityAttribute attr)
		{
			PermissionSet permSet = new PermissionSet(PermissionState.None);
			permSet.AddPermission(attr.CreatePermission());
			SecurityElement element = permSet.ToXml();
			PermissionSet permSet2 = new PermissionSet(PermissionState.None);
			permSet2.FromXml(element);
			permSet2.Demand();
		}
		
		[Test]
		[ExpectedException(typeof(SecurityException))]
		public void TestInvalidPermission()
		{
			AuthorizationProviderPermission perm = new AuthorizationProviderPermission("Admins");
			perm.Demand();
		}

		[Test]
		public void TestValidPermission()
		{
			AuthorizationProviderPermission perm = new AuthorizationProviderPermission("ManagersRule");
			perm.Demand();
		}
		
		[Test]
		[ExpectedException(typeof(SecurityException))]
		public void AuthorizationProviderPermissionInvalid()
		{
			AuthorizationProviderPermissionAttribute attr = new AuthorizationProviderPermissionAttribute(SecurityAction.Demand);
			attr.Rule = "Admins";
			DemandAttribute(attr);
		}
	
		[Test]
		public void AuthorizationProviderPermissionValid()
		{
			AuthorizationProviderPermissionAttribute attr = new AuthorizationProviderPermissionAttribute(SecurityAction.Demand);
			attr.Rule = "ManagersRule";
			DemandAttribute(attr);
		}


		[AuthorizationProviderPermission(SecurityAction.Demand, Rule="Admins")]
		public void CallMe()
		{
			GetMethodAttributes(MethodInfo.GetCurrentMethod());
		}
		
		[Test]
		public void ShouldFail()
		{
			GetMethodAttributes(MethodInfo.GetCurrentMethod());
			CallMe();
		}

		public void GetMethodAttributes(MemberInfo info)
		{
			Attribute[] attrs = Attribute.GetCustomAttributes(info);
			foreach(Attribute attr in attrs) 
			{
				System.Diagnostics.Debug.WriteLine("   {0}",	attr.GetType().ToString());
			}
		}


//		[Test]
//		[AuthorizationProviderPermission(SecurityAction.Demand,Rule="ManagersRule")]
//		public void ValidAuthorization()
//		{
//			Assert.IsTrue(true);
//		}

	}
}
#endif