using System.ComponentModel;
using System.Diagnostics;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design;
using Microsoft.Practices.EnterpriseLibrary.Configuration.Design.Validation;
using Microsoft.Practices.EnterpriseLibrary.Security.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security.Configuration.Design;

namespace EAF.Security.AzManRoles.Configuration.Design
{
    /// <summary>
    /// Node representing configuration from <see cref="AzManRolesProviderData"/>.
    /// </summary>
    public class AzManRolesProviderNode : RolesProviderNode
    {
        private const string storeLocation = "msxml://c:/myAuthStore.xml";
        private const string applicationName = "My Application";
        private static readonly string scopeName = string.Empty;

        private AzManRolesProviderData azManRolesProviderData;

		/// <summary>
		/// Default constructor
		/// </summary>
        public AzManRolesProviderNode() : this(new AzManRolesProviderData(SR.AzManRolesProvider, storeLocation, applicationName, scopeName))
        {
        }

		/// <summary>
		/// Constructor for AzManRolesProviderDataNode.
		/// </summary>
		/// <param name="azManRolesProviderData">Configuration data for <see cref="AzManRolesProvider"></see></param>
        public AzManRolesProviderNode(AzManRolesProviderData azManRolesProviderData) : base(azManRolesProviderData)
        {
            this.azManRolesProviderData = azManRolesProviderData;
        }

        /// <summary>
        /// See <see cref="AzManRolesProviderData.Application"/>.
        /// </summary>
        [Required]
        [SRDescription(SR.Keys.ApplicationDescription)]
        public string Application
        {
            get { return azManRolesProviderData.Application; }
            set { azManRolesProviderData.Application = value; }
        }

        /// <summary>
        /// See <see cref="AzManRolesProviderData.Scope"/>.
        /// </summary>
        [SRDescription(SR.Keys.ScopeDescription)]
        public string Scope
        {
            get { return azManRolesProviderData.Scope; }
            set { azManRolesProviderData.Scope = value; }
        }

        /// <summary>
        /// See <see cref="AzManRolesProviderData.StoreLocation"/>.
        /// </summary>
        [Required]
        [SRDescription(SR.Keys.StoreLocationDescription)]
        public string StoreLocation
        {
            get { return azManRolesProviderData.StoreLocation; }
            set { azManRolesProviderData.StoreLocation = value; }
        }

        /// <summary>
        /// The fully qualified type name for the AzMan provider 
        /// </summary>
        [Browsable(false)]
        public override string TypeName
        {
            get { return typeof(AzManRolesProvider).AssemblyQualifiedName; }
        }

        /// <summary>
        /// See <see cref="RolesProviderNode.RolesProviderData"/>.
        /// </summary>
        [Browsable(false)]
        public override RolesProviderData RolesProviderData
        {
            get { return base.RolesProviderData; }
        }
    }
}