
#if  UNIT_TESTS
using System;
using System.Configuration;
using System.IO;
using System.Management;
using System.Security;
using System.Security.Principal;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security;
using Microsoft.Practices.EnterpriseLibrary.Security.AzMan.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security.Configuration;
using NUnit.Framework;

using EAF.Security.AzManRoles.Configuration;


namespace EAF.Security.AzManRoles.Tests
{
    [TestFixture]
    public class AzManRoleFixture
    {
        private AzManRolesProvider azman;
        private AzManRolesProviderData data = new AzManRolesProviderData();
        private static readonly string scope = "http://entlib.com";

        [SetUp]
        public void Setup()
        {
            data.Application = "Enterprise Library Unit Test";
            data.Scope = "";
            data.StoreLocation = @"msxml://{currentPath}/testAzStore.xml";
            azman = new AzManRolesProvider();
            azman.Initialize(new TestRolesProviderConfigurationView(data, new ConfigurationContext()));
            ReplaceSIDinConfigFile();
		}

        [Test]
        public void GetRoles()
        {
			IPrincipal principal = azman.GetRoles(WindowsIdentity.GetCurrent());
			
			Assert.IsNotNull(principal);
			Assert.IsTrue(principal.IsInRole("Manager"));
			Assert.IsFalse(principal.IsInRole("Employee"));

        }


        private void ReplaceSIDinConfigFile()
        {
            string sidToReplace = "S-1-5-21-839522115-764733703-1343024091-500";
            string currentSid = GetUserSID();

            // read current config file
            FileStream f = new FileStream("testAzStore.xml", FileMode.Open, FileAccess.ReadWrite, FileShare.ReadWrite);
            StreamReader r = new StreamReader(f);
            string contents = r.ReadToEnd();
            f.Close();

            // write updated config file
            f = new FileStream("testAzStore.xml", FileMode.Truncate, FileAccess.ReadWrite, FileShare.ReadWrite);
            StreamWriter w = new StreamWriter(f);
            contents = contents.Replace(sidToReplace, currentSid);
            w.Write(contents);
            w.Flush();
            f.Close();
        }

        private string GetUserSID()
        {
            string currentSid = "";
            string ident = WindowsIdentity.GetCurrent().Name;
            string domain = ident.Substring(0, ident.IndexOf(@"\"));
            string user = ident.Substring(domain.Length + 1);

            // get current users sid
            string pGroup = "ROOT\\CIMV2:Win32_Account.Domain=\"" + domain + "\",Name=\"" + user + "\"";
            ManagementPath path = new ManagementPath(pGroup);
            using (ManagementObject o = new ManagementObject(path))
            {
                currentSid = o["SID"].ToString();
            }

            return currentSid;
        }

        private class TestRolesProviderConfigurationView : SecurityConfigurationView
        {
            public AzManRolesProviderData data;

            public TestRolesProviderConfigurationView(AzManRolesProviderData data, ConfigurationContext context) : base(context)
            {
                this.data = data;
            }

            public override RolesProviderData GetRolesProviderData(string rolesProviderName)
            {
                return data;
            }
        }
    }
}

#endif