using System.Xml.Serialization;
using Microsoft.Practices.EnterpriseLibrary.Security.Configuration;

namespace EAF.Security.PortalProfile.Configuration
{
    /// <summary>
    /// Configuration data for the PortalProvider.
    /// </summary>
    [XmlRoot("profileProvider", Namespace=SecuritySettings.ConfigurationNamespace)]
    public class PortalProfileProviderData : ProfileProviderData
    {
		private string mapping;
    
        /// <summary>
        /// <para>Initialize a new instance of the <see cref="PortalProfileProviderData"/> class.</para>
        /// </summary>
        public PortalProfileProviderData() : this(string.Empty,string.Empty)
        {
        }

        /// <summary>
        /// <para>Initialize a new instance of the <see cref="PortalProfileProviderData"/> class with a name and the name of a database instance.</para>
        /// </summary>
        /// <param name="name">
        /// <para>The name of the provider.</para>
        /// </param>
        /// <param name="database">
        /// <para>A database instance where the profile is stored.</para>
        /// </param>
        public PortalProfileProviderData(string name, string mapper) : base(name)
        {
			this.mapping = mapping;
        }

		/// <summary>
		/// Gets or sets the configured DataMapping name.
		/// </summary>
		/// <value>The configured DataMapping instance.</value>
		[XmlAttribute("mapping")]
		public string Mapping
		{
			get { return this.mapping; }
			set { this.mapping = value; }
		}

		/// <summary>
        /// Gets the assembly qualified name of this provider.
        /// </summary>
        [XmlIgnore]
        public override string TypeName
        {
            get { return typeof(PortalProfileProvider).AssemblyQualifiedName; }
            set
            {
            }
        }
    }
}