#if  UNIT_TESTS
using System;
using System.Collections;
using System.Security.Principal;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security;
using Microsoft.Practices.EnterpriseLibrary.Security.Database;
using EAF.Security.PortalProfile.Configuration;
using EnterpriseApplicationFramework.Data;
using NUnit.Framework;



namespace EAF.Security.PortalProfile.Tests
{
    [TestFixture]
    public class PortalProfileProviderFixture 
    {
        private GenericIdentity ident;
        private PortalProfileProvider profileProvider;
        
        [SetUp]
        public void Setup()
        {
            this.ident = new GenericIdentity("admin");
            PortalProfileProviderData data = new PortalProfileProviderData("MyProfile","Portal");
			profileProvider = new PortalProfileProvider();
			profileProvider.Initialize(new TestProfileConfigurationView(data, new ConfigurationContext()));
        }

		private PortalProfile CreatePortalProfile(string description)
		{
				PortalProfile profile = new PortalProfile();
				profile.PortalProfiles.AddPortalProfilesRow(3,3,DateTime.Now,"TestTitle","http://testme","http://mobiletestme",1,description);
				return profile;
		}
		
		[Test]
        public void CreateFromFactory()
        {
            IProfileProvider portalProfile = ProfileFactory.GetProfileProvider("MyProfile");
			portalProfile.SetProfile(this.ident,CreatePortalProfile("description"));

			PortalProfile profile2 = (PortalProfile)portalProfile.GetProfile(this.ident);
			Assert.IsNotNull(profile2);
            Assert.AreEqual(profile2.PortalProfiles[profile2.PortalProfiles.Count-1].Description,"description");
        }

        [Test]
        public void SetProfileForMultipleUsers()
        {
            GenericIdentity ident1 = new GenericIdentity("lfenster");
            GenericIdentity ident2 = new GenericIdentity("Lenny");

            profileProvider.SetProfile(ident1, CreatePortalProfile("descrition for lfenster"));
            profileProvider.SetProfile(ident2, CreatePortalProfile("descrition for Lenny"));

			PortalProfile profile2 = (PortalProfile)profileProvider.GetProfile(ident1);
			PortalProfile profile3 = (PortalProfile)profileProvider.GetProfile(ident2);

			Assert.IsNotNull(profile2);
			Assert.AreEqual(profile2.PortalProfiles[profile2.PortalProfiles.Count-1].Description,"descrition for lfenster");
			Assert.IsNotNull(profile3);
			Assert.AreEqual(profile3.PortalProfiles[profile3.PortalProfiles.Count-1].Description,"descrition for Lenny");
		}

        [Test]
        [ExpectedException(typeof(DataMapperException))]
        public void SetProfileForInvalidUser()
        {
            GenericIdentity ident1 = new GenericIdentity("INVALID");
            profileProvider.SetProfile(ident1, CreatePortalProfile("descrition INVALID"));
        }

        [Test]
        public void GetProfileForInvalidUser()
        {
            GenericIdentity ident1 = new GenericIdentity("INVALID");
            PortalProfile profile = (PortalProfile)profileProvider.GetProfile(ident1);
            Assert.AreEqual(profile.PortalProfiles.Count,0);
        }

        [Test]
        public void DeleteUserWithAProfile()
        {
            UserRoleManager urm = new UserRoleManager("Portal", new ConfigurationContext());
            urm.CreateUser("testuser", ASCIIEncoding.ASCII.GetBytes("Password"));

            GenericIdentity ident1 = new GenericIdentity("testuser");
			profileProvider.SetProfile(ident1, CreatePortalProfile("descrition for testuser"));
			
            try
            {
                urm.DeleteUser("testuser");
            }
            catch (Exception ex)
            {
                Assert.Fail("no exception should occur when deleting a user: " + ex.Message);
            }
        }

    }
}

#endif