using System;
using System.Data;
using System.Xml;
using System.Diagnostics;

namespace XmlFileProvider
{
	/// <summary>
	/// Summary description for XmlFileCommand.
	/// </summary>
	public class XmlFileCommand : IDbCommand
	{
		#region "Private member variables"
			CommandType commandType;
			string	commandText;
			XmlFileConnection connection;
			UpdateRowSource source = UpdateRowSource.None;
			IDataParameterCollection parameters = new XmlFileParameterCollection();
			IDbTransaction transaction;

		#endregion


		private void NotSupported()
		{
			throw new System.NotSupportedException();
		}

		private void NotImpl()
		{
			throw new System.NotImplementedException();
		}
		
		public XmlFileCommand()
		{
		}
	
		public XmlFileCommand(string command)
		{
			commandText = command;
		}
		
		public XmlFileCommand(string command, XmlFileConnection connection)
		{
			Debug.WriteLine("XmlFileCommand.constructor", "XmlFileCommand");
			commandText = command;
			connection = connection;
		}

		#region IDbCommand Members

		public void Cancel()
		{
			NotSupported();
		}

		public void Prepare()
		{
		}

		public CommandType CommandType
		{
			get 
			{
				return commandType;
			}
			set 
			{ 
				// only need to support text per SDK
				commandType = value;
			}
		}

		public IDataReader ExecuteReader(CommandBehavior behavior)
		{
			Debug.WriteLine("XmlFileCommand.ExecuteReader(behavior)", "XmlFileCommand"); 

			// must have a valid and open connection 
			if (connection == null || connection.State != ConnectionState.Open) 
				throw new InvalidOperationException(SR.ExceptionConnectionOpen); 


			if ((behavior & CommandBehavior.KeyInfo) > 0)
				Debug.WriteLine("Behavior includes KeyInfo");

			if ((behavior & CommandBehavior.SchemaOnly) > 0)
				Debug.WriteLine("Behavior includes SchemaOnly");

			return ExecuteReader();
		}

		public IDataReader ExecuteReader()
		{
			// must have a valid and open connection 
			if (connection == null || connection.State != ConnectionState.Open) 
				throw new InvalidOperationException(SR.ExceptionConnectionOpen); 

			XmlFileDataReader reader = new XmlFileDataReader(connection.Database);	//database == filename
			return reader;
		}
	
		IDataReader System.Data.IDbCommand.ExecuteReader()
		{
			// must have a valid and open connection 
			if (connection == null || connection.State != ConnectionState.Open) 
				throw new InvalidOperationException(SR.ExceptionConnectionOpen); 

			XmlFileDataReader reader = new XmlFileDataReader(connection.Database);	//database == filename
			return reader;
		}

		public XmlReader ExecuteXmlReader()
		{
			// must have a valid and open connection 
			if (connection == null || connection.State != ConnectionState.Open) 
				throw new InvalidOperationException(SR.ExceptionConnectionOpen); 

			XmlFileDataReader reader = new XmlFileDataReader(connection.Database);	
			return reader.XmlReader;
		}

		public object ExecuteScalar()
		{
			NotImpl();
			return null;
		}

		//updates file and returns number of records
		public int ExecuteNonQuery()
		{
			// must have a valid and open connection 
			if (connection == null || connection.State != ConnectionState.Open) 
				throw new InvalidOperationException(SR.ExceptionConnectionOpen); 

			int recs;
			XmlFileDataReader reader = (XmlFileDataReader)ExecuteReader();
			recs = reader.RecordsAffected;
			reader.Close();
			return recs;
		}

		public int CommandTimeout
		{
			get 
			{ 
				return connection.ConnectionTimeout;
			}
			set 
			{ 
				if (value != 0)
					NotSupported();
			}
		}

		public IDbDataParameter CreateParameter()
		{
			this.NotSupported();
			return null;
		}

		public IDbConnection Connection
		{
			get 
			{ 
				return connection;
			}
			set 
			{ 
				if (value.GetType() == typeof(XmlFileConnection))
					connection = (XmlFileConnection)value;
				else
				{
					throw new InvalidOperationException(SR.ExceptionMustBeXmlFileConnection); 
				}
			}
		}

		public UpdateRowSource UpdatedRowSource
		{
			get 
			{ 
				return source;
			}
			set 
			{ 
				source = value;
			}
		}

		public string CommandText
		{
			get 
			{ 
				return commandText;
			}
			set 
			{ 
				//TODO: change this functionality so it actually does a select on a dataset; i.e., filters the data
				commandText = value;
			}
		}

		public IDataParameterCollection Parameters
		{
			get 
			{ 
				return parameters;
			}
		}

		public IDbTransaction Transaction
		{
			get 
			{ 
				NotSupported();
				return transaction;
			}
			set 
			{ 
				NotSupported();
				transaction = value;
			}
		}

		#endregion

		#region IDisposable Members

		public void Dispose()
		{
			// TODO:  Add XmlFileCommand.Dispose implementation
		}

		#endregion
	}
}
