using System;
using System.Diagnostics;
using System.Data;
using System.Xml;
using System.Collections.Specialized;

namespace XmlFileProvider
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class XmlFileConnection : IDbConnection, ICloneable
	{
		#region "Private member variables"
			private string origConnString;
			private string fileName;
			private StringCollection parameters;
			private ConnectionState state = ConnectionState.Closed;
			private int connectionTimeout = 0;
		#endregion

		private void NotSupported()
		{
			throw new System.NotSupportedException();
		}

		private void NotImpl()
		{
			throw new System.NotImplementedException();
		}

		public XmlFileConnection()
		{
		}

		public XmlFileConnection(string strConnectionString)
		{
			ConnectionString = strConnectionString;
		}

		public IDbTransaction BeginTransaction(IsolationLevel iso)
		{
			return new XmlFileTransaction(this,iso);
		}

		public IDbTransaction BeginTransaction()
		{
			return new XmlFileTransaction(this);
		}

		public void ChangeDatabase(string newdb)
		{
			if (! newdb.Equals(fileName)) fileName = newdb;
			return; 
		}

		public void Close() 
		{
			state = ConnectionState.Closed;
			return;
		}

		public IDbCommand CreateCommand()
		{
			IDbCommand idbCommand = (IDbCommand)(new XmlFileCommand());
			idbCommand.Connection = this;
			return idbCommand; 
		}

		public void Open()
		{ 
			state = ConnectionState.Open;
		}
		
		// always return what the user set
		public string ConnectionString
		{
			get 
			{ 
				return origConnString;
			}
			set 
			{ 
				origConnString = value;
				fileName = String.Empty;
				if (parameters == null)
					parameters = new StringCollection();
				parameters.Clear();
				string[] arrConnString = System.Text.RegularExpressions.Regex.Split(value,";,");
				foreach (string strParam in arrConnString)
				{
					if (fileName.Equals(String.Empty))
						fileName = strParam;
					else
						parameters.Add(strParam);
				}
			}
		}

		public int ConnectionTimeout
		{
			get 
			{
				return connectionTimeout;
			}
		}

		public string Database
		{
			get 
			{ 
				return fileName;
			}
		}

		public ConnectionState State
		{
			get 
			{
				return state;
			}
		}
	
		#region IDisposable Members

		public void Dispose()
		{
		}

		#endregion
	
		#region ICloneable Members

		public object Clone()
		{
			return new XmlFileConnection(ConnectionString);
		}

		#endregion
	}
}	
