using System;
using System.Diagnostics;
using System.Collections;
using System.Data;
using System.Xml;
namespace XmlFileProvider
{
	/// <summary>
	/// Summary description for XmlFileParameter.
	/// </summary>
	public class XmlFileParameter : IDataParameter
	{
			DbType paramDbType  = DbType.Object;
			ParameterDirection parameterDirection = ParameterDirection.Input;
			bool isNullable  = false;
			string paramName;
			string sourceColumn;
			DataRowVersion dataRowVersion = DataRowVersion.Current;
			object paramValue;
		
		public XmlFileParameter() {}
	
		public XmlFileParameter(string parameterName, DbType type)
		{
			this.ParameterName = parameterName;
			this.DbType = type;
		}

		public XmlFileParameter(string parameterName, object value)
		{
			this.ParameterName = parameterName;
			this.Value = value;
		}

		public XmlFileParameter(string parameterName, DbType dbType, string sourceColumn)
		{
			this.ParameterName = parameterName;
			this.DbType = dbType;
			this.SourceColumn = sourceColumn;
		}

		public String ParameterName 
		{
			get { return paramName; }
			set { paramName = value; }
		}		
		
		public ParameterDirection Direction 
		{
			get { return parameterDirection; }
			set { parameterDirection = value; }
		}

		public Boolean IsNullable 
		{
			get { return isNullable; }
		}

		public String SourceColumn 
		{
			get { return sourceColumn; }
			set { sourceColumn = value; }
		}

		public DataRowVersion SourceVersion 
		{
			get { return dataRowVersion; }
			set { dataRowVersion = value; }
		}

		public object Value 
		{
			get
			{
				return this.paramValue;
			}
			set
			{
				this.paramValue    = value;
				paramDbType  = _inferType(value);
			}
		}

		private DbType _inferType(Object value)
		{
			switch (Type.GetTypeCode(value.GetType()))
			{
				case TypeCode.Empty:
					throw new SystemException(SR.InvalidDataType);

				case TypeCode.Object:
					return DbType.Object;

				case TypeCode.DBNull:
				case TypeCode.Char:
				case TypeCode.SByte:
				case TypeCode.UInt16:
				case TypeCode.UInt32:
				case TypeCode.UInt64:
					// Throw a SystemException for unsupported data types.
					throw new SystemException(SR.InvalidDataType);

				case TypeCode.Boolean:
					return DbType.Boolean;

				case TypeCode.Byte:
					return DbType.Byte;

				case TypeCode.Int16:
					return DbType.Int16;

				case TypeCode.Int32:
					return DbType.Int32;

				case TypeCode.Int64:
					return DbType.Int64;

				case TypeCode.Single:
					return DbType.Single;

				case TypeCode.Double:
					return DbType.Double;

				case TypeCode.Decimal:
					return DbType.Decimal;

				case TypeCode.DateTime:
					return DbType.DateTime;

				case TypeCode.String:
					return DbType.String;

				default:
					throw new SystemException(SR.UnknownDataType);
			}
		}
		
		public DbType DbType 
		{
			get  { return this.paramDbType; }
			set  { this.paramDbType = value;  }
		}
	}
}
