using System;
using System.Data;
using System.Collections;
using System.Globalization;

namespace XmlFileProvider
{
	/// <summary>
	/// Summary description for XmlFileParameterCollection.
	/// </summary>

		public class XmlFileParameterCollection : ArrayList, IDataParameterCollection
		{
			public object this[string index] 
			{
				get
				{
					return this[IndexOf(index)];
				}
				set
				{
					this[IndexOf(index)] = value;
				}
			}
		
			public XmlFileParameterCollection()
			{
			}
			
			public bool Contains(string parameterName)
			{
				return(-1 != IndexOf(parameterName));
			}

			public int IndexOf(string parameterName)
			{
				int index = 0;
				foreach(XmlFileParameter item in this) 
				{
					if (0 == _cultureAwareCompare(item.ParameterName, parameterName))
					{
						return index;
					}
					index++;
				}
				return -1;
			}

			public void RemoveAt(string parameterName)
			{
				RemoveAt(IndexOf(parameterName));
			}

			public override int Add(object value)
			{
				return Add((XmlFileParameter)value);
			}

			public int Add(XmlFileParameter value)
			{
				if (((XmlFileParameter)value).ParameterName != null)
				{
					return base.Add(value);
				}
				else
					throw new ArgumentException(SR.UnnamedParameter);
			}

			public int Add(string parameterName, DbType type)
			{
				return Add(new XmlFileParameter(parameterName, type));
			}

			public int Add(string parameterName, object value)
			{
				return Add(new XmlFileParameter(parameterName, value));
			}

			public int Add(string parameterName, DbType dbType, string sourceColumn)
			{
				return Add(new XmlFileParameter(parameterName, dbType, sourceColumn));
			}

			private int _cultureAwareCompare(string strA, string strB)
			{
				return CultureInfo.CurrentCulture.CompareInfo.Compare(strA, strB, CompareOptions.IgnoreKanaType | CompareOptions.IgnoreWidth | CompareOptions.IgnoreCase);
			}
		}
}
